@@ -1,5 +1,6 @@
 import typing
 import inspect
+import warnings
 
 try:
     from pydantic import create_model
@@ -7,9 +8,9 @@ try:
 except ImportError:
 
     def create_model(*args, **kwargs):  # type: ignore
-        raise NotImplementedError()
+        raise NotImplementedError("Need install `pydantic` from pypi.")
 
-    BaseModel = None  # type: ignore
+    BaseModel = type("BaseModel", (), {})  # type: ignore
 
 Callable = typing.TypeVar("Callable", bound=typing.Callable)
 
@@ -36,9 +37,16 @@ def set_type_model(func: Callable) -> Callable:
         else:
             field_definitions[name] = (parameter.annotation, parameter.default)
     if field_definitions:
-        body_model = create_model(func.__name__, **field_definitions)
-        setattr(func, "__body_model__", body_model)
-
+        try:
+            body_model = create_model(func.__name__, **field_definitions)
+            setattr(func, "__body_model__", body_model)
+        except NotImplementedError:
+            message = (
+                "If you wanna using type hint "
+                "to create OpenAPI docs or convert type, "
+                "please install `pydantic` from pypi."
+            )
+            warnings.warn(message, ImportWarning)
     return func
 
 
@@ -46,31 +54,28 @@ TEMPLATE = """<!DOCTYPE html>
 <html>
 
 <head>
-    <title>OpenAPI power by rpc.py</title>
-    <meta charset="utf-8" />
-    <meta name="viewport" content="width=device-width, initial-scale=1">
-
-    <style>
-        * {
-            font-family: Menlo, Consolas, "Source Code Pro", Inconsolata, Monaco, "Courier New",
-                'Segoe UI', Helvetica, Arial, sans-serif !important;
-        }
-
-        h1,
-        h2 {
-            font-family: 'Segoe UI', Helvetica, Arial, sans-serif !important;
-        }
-
-        body {
-            margin: 0;
-            padding: 0;
-        }
-    </style>
+    <link type="text/css" rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3.30.0/swagger-ui.css">
+    <title>OpenAPI Docs</title>
 </head>
 
 <body>
-    <redoc spec-url='get-openapi-docs'></redoc>
-    <script src="https://cdn.jsdelivr.net/npm/redoc@next/bundles/redoc.standalone.js"> </script>
+    <div id="swagger-ui"></div>
+    <script src="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3.30.0/swagger-ui-bundle.js"></script>
+    <script>
+        const ui = SwaggerUIBundle({
+            url: './get-openapi-docs',
+            dom_id: '#swagger-ui',
+            presets: [
+                SwaggerUIBundle.presets.apis,
+                SwaggerUIBundle.SwaggerUIStandalonePreset
+            ],
+            layout: "BaseLayout",
+            deepLinking: true,
+            showExtensions: true,
+            showCommonExtensions: true
+        })
+
+    </script>
 </body>
 
 </html>
